from __future__ import annotations

__all__ = [
    "time_s",
    "time_ms",
    "time_us",
    "time_ns",
    "time_monotonic_s",
    "time_monotonic_ms",
    "time_monotonic_us",
    "time_monotonic_ns",
    "iso8601_to_unix",
    "time_iso8601",
]

def time_s() -> int: ...
def time_ms() -> int: ...
def time_us() -> int: ...
def time_ns() -> int: ...
def time_monotonic_s() -> int: ...
def time_monotonic_ms() -> int: ...
def time_monotonic_us() -> int: ...
def time_monotonic_ns() -> int: ...
def iso8601_to_unix(timestamp: str) -> float: ...
def time_iso8601(timestamp: float = 0.0) -> str: ...
